package com.ruoyi.system.service;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.staffTrain.StaffTrainManual;

import java.util.List;


/**
 * 员工培训手册Service接口
 * 
 * @author boman
 * @date 2025-02-18
 */
public interface IStaffTrainManualService 
{
    /**
     * 查询员工培训手册
     * 
     * @param manualId 员工培训手册主键
     * @return 员工培训手册
     */
    public StaffTrainManual selectStaffTrainManualByManualId(Long manualId);

    /**
     * 查询员工培训手册列表
     * 
     * @param staffTrainManual 员工培训手册
     * @return 员工培训手册集合
     */
    public List<StaffTrainManual> selectStaffTrainManualList(StaffTrainManual staffTrainManual);

    /**
     * 新增员工培训手册
     * 
     * @param staffTrainManual 员工培训手册
     * @return 结果
     */
    public int insertStaffTrainManual(StaffTrainManual staffTrainManual);

    /**
     * 修改员工培训手册
     * 
     * @param staffTrainManual 员工培训手册
     * @return 结果
     */
    public int updateStaffTrainManual(StaffTrainManual staffTrainManual);

    /**
     * 批量删除员工培训手册
     * 
     * @param manualIds 需要删除的员工培训手册主键集合
     * @return 结果
     */
    public int deleteStaffTrainManualByManualIds(Long[] manualIds);

    /**
     * 删除员工培训手册信息
     * 
     * @param manualId 员工培训手册主键
     * @return 结果
     */
    public int deleteStaffTrainManualByManualId(Long manualId);

    /**
     * 获取已读人员名单
     */
    public AjaxResult getRead(StaffTrainManual staffTrainManual);
}
